{% load i18n %}
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>{% trans "Signed out" %}</title>
</head>
<body>
<h2>{% trans "You have signed out successfully." %}</h2>
<hr>
<p>{% trans "If you want to login again or switch to another account, please do so in SSO." %}</p>
</body>
</html>